#
# spec file for package etcd-for-k8s1.26
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define project go.etcd.io/etcd

Name:           etcd-for-k8s1.26
Version:        3.5.9
Release:        1.1
Summary:        Etcd and etcdtl for k8s image
License:        Apache-2.0
Group:          System/Management
URL:            https://github.com/etcd-io/etcd
Source:         etcd-%{version}.tar.gz
Source1:        vendor-etcdctl.tar.gz
Source2:        vendor-server.tar.gz
BuildRequires:  golang-packaging
BuildRequires:  golang(API) >= 1.19
ExcludeArch:    %ix86
ExcludeArch:    s390
Conflicts:      etcd
Conflicts:      etcdctl
Provides:       etcd-for-k8s = %{version}
Conflicts:      etcd-for-k8s

%description
etcd is a distributed, consistent key-value store for shared configuration and
service discovery. This package contains different versions of etcd and
etcdctl for the kubernetes container image.

%prep
%setup -q -n etcd-%{version}

%build
%{goprep} %{project}

tar -xf %{SOURCE1} -C ./etcdctl
tar -xf %{SOURCE2} -C ./server

mkdir ./bin

cd ./etcdctl
go build -v -buildmode=pie -mod=vendor -o ../bin/etcdctl
cd ..

cd ./server
go build -v -buildmode=pie -mod=vendor -o ../bin/etcd
cd ..

%install
install -d %{buildroot}/%{_bindir}
install -d %{buildroot}/%{_sbindir}
install -D -p -m 0755 bin/etcdctl %{buildroot}%{_bindir}/etcdctl-%{version}
install -D -p -m 0755 bin/etcd %{buildroot}%{_sbindir}/etcd-%{version}

ln -sf etcdctl-%{version} %{buildroot}%{_bindir}/etcdctl
# ln -sf etcd-%{version} %{buildroot}%{_sbindir}/etcd
# we need a wrapper script to be able to set some environment variables.
echo "#!/bin/bash" > %{buildroot}%{_sbindir}/etcd
%ifarch aarch64
echo "export ETCD_UNSUPPORTED_ARCH=arm64" >> %{buildroot}%{_sbindir}/etcd
%endif
echo "exec %{_sbindir}/etcd-%{version} \"\$@\"" >> %{buildroot}%{_sbindir}/etcd
chmod 755 %{buildroot}%{_sbindir}/etcd

%files
%defattr(-,root,root)
%license LICENSE
%{_sbindir}/etcd
%{_sbindir}/etcd-%{version}
%{_bindir}/etcdctl
%{_bindir}/etcdctl-%{version}

%changelog
* Thu Oct 26 2023 Priyanka Saggu <priyanka.saggu@suse.com>
- Update to version 3.5.9:
  (as per https://github.com/kubernetes/kubernetes/blob/v1.26.10/build/dependencies.yaml#L58)
  * Move go version to dedicated .go-version file
  * tests: e2e and integration test for timetolive
  * etcdserver: protect lease timetilive with auth
  * Backport go update to latest patch release 1.19.9.
  * Backport centralising go version for actions workflows.
  * server: backport 15743, improved description of --initial-cluster-state flag
  * etcdserver: Guarantee order of requested progress notifications
  * etcdserver: verify field 'username' and 'revision' present when decoding a JWT token
  * set zap logging to wsproxy
  * security: remove password after authenticating the user
  * test: add an e2e test to reproduce https://nvd.nist.gov/vuln/detail/CVE-2021-28235
  * bump golang to 1.19.8
  * server/auth: disallow creating empty permission ranges
  * chore: enable strict mode for test CI
  * Fixes: #15266 All docker images of Architecture show amd64
  * scripts: Add testing of etcd in local image in release workflow.
  * server: Fix defer function closure escape
  * tests: Test separate http port connection multiplexing
  * server: Add --listen-client-http-urls flag to allow running grpc server separate from http server
  * server: Pick one address that all grpc gateways connect to
  * server: Extract resolveUrl helper function
  * server: Separate client listener grouping from serving
  * refactor: Use proper variable names for urls
  * sever/auth: fix addUserWithNoOption of store_test
  * server/auth: fix auth panic bug when user changes password
  * Automated cherry-pick of #14860: Trigger release in current branch for github workflow case
  * server/embed: fix data race when start insecure grpc
  * server: Test watch restore
  * mvcc: update minRev when watcher stays synced
  * tests: Add v2 API to connection multiplexing test
  * tests: Add connection muiltiplexer testing
  * tests: Backport RunUtilCompletion
  * tests: Backport tls for etcdctl
  * tests: Extract e2e test utils
  * tests: Allow specifying http version in curl
  * tests: Refactor newClient args
  * tests: Refactor CURLPrefixArgs
  * Backport tls 1.3 support.
  * server: Switch back to random scheduler to improve resilience to watch starvation
  * test: Test etcd watch stream starvation under high read response load when sharing the same connection
  * tests: Allow configuring progress notify interval in e2e tests
  * Backport go_srcs_in_module changes and fix goword failures.
  * Bump golang.org/x/net to v0.7.0 to address CVE GO-2023-1571.
  * test:enhance the test case TestV3WatchProgressOnMemberRestart
  * clientv3: correct the nextRev on receving progress notification response
  * etcdserver: add failpoints walBeforeSync and walAfterSync
  * Fix regression in timestamp resolution
  * upgrade cockroachdb/datadriven to v1.0.2 to remove archived dependencies
  * bump github.com/stretchr/testify to v1.8.1
  * bump bbolt to v1.3.7 for release-3.5
  * netutil: consistently format ipv6 addresses
  * docker: remove nsswitch.conf
  * etcdserver: return membership.ErrIDNotFound when the memberID not found
  * etcdserver: process the scenaro of the last WAL record being partially synced to disk
  * update nsswitch.conf for 3.5
  * 3.5: remove the dependency on busybox
  * Remove dependency on gobin
  * resolve build error: parameter may not start with quote character '
  * remove .travis.yml
  * format the source code and tidy the dependencies using go 1.17.13
  * deps: bump golang.org/x/net to v0.4.0 to address CVEs
  * security: use distroless base image to address critical Vulnerabilities
  * cidc:  specify the correct branch name of release-3.5 in workflow for trivy nightly scan
  * Add trivy nightly scan for release-3.5
  * clientv3: revert the client side change in 14547
  * client/pkg/v3: fixes Solaris build of transport
  * etcdserver: fix nil pointer panic for readonly txn
  * [3.5] Backport: non mutating requests pass through quotaKVServer when NOSPACE
  * etcdserver: intentionally set the memberID as 0 in corruption alarm
* Thu Mar  9 2023 Priyanka Saggu <priyanka.saggu@suse.com>
- Initial package version 3.5.6:
  * Version specified in kubernetes-1.26 https://github.com/kubernetes/kubernetes/blob/v1.26.2/build/dependencies.yaml
